"""Core package for ADPA framework."""
from .exceptions import (
    ADPAError,
    ConfigurationError,
    ValidationError,
    ProcessingError,
    ResourceError,
    AuthenticationError,
    AuthorizationError,
    RateLimitError,
    DatabaseError,
    NetworkError,
    TimeoutError,
    ConcurrencyError,
    NotFoundError,
    DuplicateError,
    InvalidOperationError,
    LLMError,
    AgentError,
    Text2SQLError,
    MonitoringError,
    SecurityError,
    format_error,
)
from .manager import CoreManager
from .models import (
    CoreConfig,
    ProcessingResult,
    WorkflowStep,
    Workflow,
    Event,
    AppConfig,
)
from .processor import DataProcessor
from .types import (
    JSON,
    PathLike,
    Callback,
    ModelName,
    ProviderName,
    LLMConfig,
    DBConfig,
    AgentConfig,
    SQLConfig,
    SecurityConfig,
    MetricsConfig,
    DataProvider,
    Processor,
)
from .utils import (
    async_retry,
    AsyncBatcher,
    ThreadPoolManager,
    memoize,
    validate_json,
)
from .workflow import WorkflowEngine
from .events import EventSystem
from .state import StateManager

__all__ = [
    # Exceptions
    "ADPAError",
    "ConfigurationError",
    "ValidationError",
    "ProcessingError",
    "ResourceError",
    "AuthenticationError",
    "AuthorizationError",
    "RateLimitError",
    "DatabaseError",
    "NetworkError",
    "TimeoutError",
    "ConcurrencyError",
    "NotFoundError",
    "DuplicateError",
    "InvalidOperationError",
    "LLMError",
    "AgentError",
    "Text2SQLError",
    "MonitoringError",
    "SecurityError",
    "format_error",
    # Models
    "CoreConfig",
    "ProcessingResult",
    "WorkflowStep",
    "Workflow",
    "Event",
    "AppConfig",
    # Core
    "CoreManager",
    "DataProcessor",
    "WorkflowEngine",
    "EventSystem",
    "StateManager",
    # Types
    "JSON",
    "PathLike",
    "Callback",
    "ModelName",
    "ProviderName",
    "LLMConfig",
    "DBConfig",
    "AgentConfig",
    "SQLConfig",
    "SecurityConfig",
    "MetricsConfig",
    "DataProvider",
    "Processor",
    # Utils
    "async_retry",
    "AsyncBatcher",
    "ThreadPoolManager",
    "memoize",
    "validate_json",
]
